# dash-google-charts

A google charts component for Plotly Dash built on top of [react-google-charts][rgc].

This is still pretty experimental, interface and features could change.


[rgc]: https://react-google-charts.com/
